@@ -184,7 +184,7 @@ class AsynctionSocketIO(SocketIO):
         namespace: str,
         channel_handlers: Optional[ChannelHandlers],
         channel_bindings: Optional[ChannelBindings],
-        server_security: Sequence[SecurityRequirement],
+        security: Sequence[SecurityRequirement],
     ) -> None:
         on_connect = _noop_handler
 
@@ -196,10 +196,10 @@ class AsynctionSocketIO(SocketIO):
                 with_bindings_validation = bindings_validator_factory(channel_bindings)
                 on_connect = with_bindings_validation(on_connect)
 
-        if server_security:
+        if security:
             # create a security handler wrapper
             with_security = security_handler_factory(
-                server_security, self.spec.components.security_schemes
+                security, self.spec.components.security_schemes
             )
             # apply security
             on_connect = with_security(on_connect)
@@ -237,11 +237,14 @@ class AsynctionSocketIO(SocketIO):
 
                     self.on_event(message.name, handler, namespace)
 
+            security = (
+                channel.x_security
+                if channel.x_security is not None
+                else server_security
+            )
+
             self._register_namespace_handlers(
-                namespace,
-                channel.x_handlers,
-                channel.bindings,
-                server_security=server_security,
+                namespace, channel.x_handlers, channel.bindings, security
             )
 
         if default_error_handler is not None:
